@@ -188,7 +188,7 @@ class Notification(NotificationAbstractModel):
             upd_notif = cache.get(cls.notification_key(user), default={})
             if (user_notif := UserNotification.objects.filter(
                 id=user_notif_id,
-                notification_type=NotificationAbstractModel.TypeChoices.WEB
+                notification__notification_type=NotificationAbstractModel.TypeChoices.WEB
             ).first()) is not None:
                 user_notif.update_unseen_cache(unseen=upd_notif)
 
